#
# Makefile Template for Tessy
# Compiler: Microchip XC8
# Debugger: Microchip MPLAB X
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE            :=
# COMPILER_DEFINES       :=
# COMPILER_INCLUDES      :=
# COMPILER_INSTALL_PATH  :=
# CHIP                   :=
# COMPILER_DEFINES       :=
# COMPILER_INCLUDES      :=
# COMPILER_INSTALL_PATH  :=
# ENDIANESS              :=
# EXEFILE_EXTENSION      :=
# LINKER_FILE            :=
# MODULE_PATH            :=
# MODULE_PATH_DOS        :=
# OBJFILE_EXTENSION      :=
# PROJECTROOT            :=
# TARGET_INSTALL_PATH    :=
# TESSY_BIN              :=
# TESSY_SYS              :=
# TESTOBJECT             :=
# TIMER_FILE             :=
# TARGET_INSTALL_PATH    :=
# TIMER_FILE             :=
# USER_LINK_OPTIONS      :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

# Chip          := PIC18F242
TESSY_SYS_DOS   := $(shell ts_pathname -s '$(TESSY_SYS)')
MPLAB_HOME      := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
LINK_FILE_SHORT := $(shell ts_pathname -s '$(LINKER_FILE)')

TS_NAME         := TS_MPLAB
IDE_NAME        := mplabx
COMPANY_NAME    := microchip
PROCESSOR_NAME  := xc8

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : check_success master slave

# Cygwin work around.
S_BUILDIN_TESSY_FLAG := $(wildcard $(MODULE_PATH)/tslows_builtin.tessy)

check_success :
ifneq ($(S_BUILDIN_TESSY_FLAG),)
	@echo *
	@echo * Obviously the last build failed. Cleaning up built-in files...
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo * Please, try again to generate a built-in target binary.
	@echo *
	@exit 1
endif


#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE     := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE     := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#
S_CC            := $(MPLAB_HOME)\bin\xc8.exe
S_LINK          := $(MPLAB_HOME)\bin\xc8.exe
S_INCLUDES      := -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)
S_STUB_OBJECT   := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT     := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)
S_COMP_OPTIONS  := --pass1 $(COMPILER_DIALECT) --chip=$(CHIP) -Q -G --double=32 --float=32 --emi=wordwrite -N255 --warn=0 \
                   --asmlist --opt=none,-asm,-asmfile,-speed,-space,+debug,-9 --addrqual=require --mode=free -P \
                   --output=default,-inhx032 --runtime=default,+clear,+init,-keep,-no_startup,+download,+config,+clib,+plib \
						 --output=-mcof,+elf -DTESSY -DTS_SLAVE -D$(TS_NAME)
S_LINK_OPTIONS  := --chip=$(CHIP) -G -m"$(MODULE_PATH_DOS)\ts_$(TESTOBJECT).map" --double=32 \
                   --float=32 --emi=wordwrite --opt=none,-asm,-asmfile,-speed,+space,+debug,-9 \
                   --addrqual=ignore --mode=free -P -N255 --warn=0 --asmlist \
						 --output=default,-inhx032 --runtime=default,+clear,+init,-keep,-no_startup,+download,+config,+clib,+plib --output=-mcof,+elf \
						 $(LINK_FILE_SHORT)

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -O"$@" "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

ifneq ($(S_GenerateBuiltinData),)
TARGET_FLAG := d
BUILTIN_OBJ := $(MODULE_PATH_DOS)\tslows_builtin$(OBJFILE_EXTENSION)
master :
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin$(OBJFILE_EXTENSION)
else
BUILTIN_OBJ :=
TARGET_FLAG := s
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
endif
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION)

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -O"$@" $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -O"$@" $<


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) -O"$@" $(S_COMP_OPTIONS) $(S_INCLUDES) $<

ifeq ("true","$(USE_BOARD_FILES)")
XC8_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
            $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) -O"$@" $(S_COMP_OPTIONS) $(COMM_INCLUDES) $< -I"$(INITOBJDIR)"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_CC) -O"$@" $(S_COMP_OPTIONS) $(COMM_INCLUDES) $< -I"$(INITOBJDIR)"
endif


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION): $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
																			$(S_SRC_OBJECTS) \
																			$(XC8_OBJS) \
																			$(S_UC_OBJECT) \
																			$(S_STUB_OBJECT) \
																			$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) $(XC8_OBJS) \
				 $(S_OBJECTS) $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
				 $(S_SRC_OBJECTS) $(S_UC_OBJECT) \
				 $(S_STUB_OBJECT) -O"$@"
	@-ts_rm -f "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)
ifneq ($(S_GenerateBuiltinData),)
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@-ts_cp -f "$@" "$(MODULE_PATH)\ts_$(TESTOBJECT)_$(TARGET_FLAG).X\dist\default\production"
	@echo *
	@echo * Generated target binary '$(shell ts_pathname -w $(MODULE_PATH)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION))' containing builtin data.
	@echo *
endif	

#####################################################################
#END_TARGETS
#####################################################################
